#

##

###

##

    	instrument

    	start
    		./instrument thermos start

    		options
    			./instrument thermos start --name instrument

    		ports:
    			10000
    			10001

    	structure
    		[dir] instrument-1
    			[dir] mongo_node
    				db:pouch
    					collection:card [{
    						"public": {
    							"hexadecimal string": ""
    						},
    						"private": {
    							"hexadecimal string": ""
    						},
    						"seed": {
    							"hexadecimal string": ""
    						}
    					}]

    		names:
    			./names

    		agenda:
    			./__agenda/agenda